<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#ff3333';
	$secondary_color = '#007fdb';

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays 

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$ad_position_choices = array(
		'1','2', '3','4','5','6','7','8','9','10'													
	);

	$pagination_style_choices = array(
		'choice-1' => 'Infinite Scroll',
		'choice-2' => 'Numeric'
	);	

	$latest_style_choices = array(
		'choice-1' => 'Latest Posts',
		'choice-2' => 'Editor\'s Choice'
	);	

	$sections[] = array(
		'id' => $section,
		'title' => __( 'MyPortal Theme Settings', 'myportal' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'myportal' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'myportal' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);	
	
	$options['primary-color'] = array(
		'id' => 'primary-color',
		'label'   => __( 'Primary Color', 'myportal' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);

	$options['secondary-color'] = array(
		'id' => 'secondary-color',
		'label'   => __( 'Secondary Color', 'myportal' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color // hex
	);	

	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Body Font', 'myportal' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Roboto'
	);

	$options['secondary-font'] = array(
		'id' => 'secondary-font',
		'label'   => __( 'Heading Font', 'myportal' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Roboto'
	);	

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'myportal' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['header-day-on'] = array(
		'id' => 'header-day-on',
		'label'   => __( 'Show current day on site header', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-date-on'] = array(
		'id' => 'header-date-on',
		'label'   => __( 'Show current date on site header', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-submit-on'] = array(
		'id' => 'header-submit-on',
		'label'   => __( 'Show submit link on site header', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-submit-link'] = array(
		'id' => 'header-submit-link',
		'label'   => __( 'Submit link URL', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => home_url().'/submit',
	);

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Show search form on site header', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-twitter-on'] = array(
		'id' => 'header-twitter-on',
		'label'   => __( 'Show twitter link on site header', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['header-twitter-link'] = array(
		'id' => 'header-twitter-link',
		'label'   => __( 'Twitter Page URL', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'https://twitter.com/happythemeshq',
	);

	$options['header-facebook-on'] = array(
		'id' => 'header-facebook-on',
		'label'   => __( 'Show facebook link on site header', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['header-facebook-link'] = array(
		'id' => 'header-facebook-link',
		'label'   => __( 'Facebook Page URL', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'https://www.facebook.com/happythemeshq',
	);	

	$options['mobile-nav-heading'] = array(
		'id' => 'mobile-nav-heading',
		'label'   => __( 'Mobile Menu Heading', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Menu', 'myportal'),
	);	

	$options['home-featured-on'] = array(
		'id' => 'home-featured-on',
		'label'   => __( 'Show featured & latest content on homepage', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	
	$options['featured-text'] = array(
		'id' => 'featured-text',
		'label'   => __( 'Featured Ribbon Text', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Featured', 'myportal'),
	);	
	$options['featured-slide-num'] = array(
		'id' => 'featured-slide-num',
		'label'   => __( 'Number of featured slides to show', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '3',		
	);

	$options['featured-num'] = array(
		'id' => 'featured-num',
		'label'   => __( 'Number of posts to show under the slider', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '4',		
	);	

	$options['home-latest-style'] = array(
		'id' => 'home-latest-style',
		'label'   => __( 'Posts type besides the featured slider', 'myportal' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $latest_style_choices,
		'default' => 'choice-1'	
	);	

	$options['home-latest-num'] = array(
		'id' => 'home-latest-num',
		'label'   => __( 'Number of latest posts / editor\'s choice', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '12',		
	);	

	$options['all-posts-url'] = array(
		'id' => 'all-posts-url',
		'label'   => __( 'Page URL to display all latest posts', 'myportal' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url() . '/latest',
	);	

	$options['content-ad-position'] = array(
		'id' => 'content-ad-position',
		'label'   => __( 'Post Loop - Insert Ad after post#', 'myportal' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $ad_position_choices,		
		'default' => '1',
	);

	$options['loop-author-avatar-on'] = array(
		'id' => 'loop-author-avatar-on',
		'label'   => __( 'Show author avatar on post list', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['loop-author-name-on'] = array(
		'id' => 'loop-author-name-on',
		'label'   => __( 'Show author name on post list', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['loop-date-on'] = array(
		'id' => 'loop-date-on',
		'label'   => __( 'Show published date on post list', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['loop-comment-on'] = array(
		'id' => 'loop-comment-on',
		'label'   => __( 'Show comments count on post list', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);		

	$options['loop-excerpt-on'] = array(
		'id' => 'loop-excerpt-on',
		'label'   => __( 'Show excerpt on post list', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);		

	$options['loop-excerpt-length'] = array(
		'id' => 'loop-excerpt-length',
		'label'   => __( 'Number of words to show on post loop', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '40',		
	);

	$options['pagination-style'] = array(
		'id' => 'pagination-style',
		'label'   => __( 'Pagination Style', 'myportal' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $pagination_style_choices,
		'default' => 'choice-1'
	);

	$options['pagination-loading-text'] = array(
		'id' => 'pagination-loading-text',
		'label'   => __( 'Infinite Scroll Loading Text', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Loading...', 'myportal'),
	);		

	$options['pagination-loaded-text'] = array(
		'id' => 'pagination-loaded-text',
		'label'   => __( 'Infinite Scroll Loaded Text', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('All posts loaded', 'myportal'),
	);		

	$options['single-breadcrumbs-on'] = array(
		'id' => 'single-breadcrumbs-on',
		'label'   => __( 'Show breadcrums on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Show share icons on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['single-author-avatar-on'] = array(
		'id' => 'single-author-avatar-on',
		'label'   => __( 'Show author avatar on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['single-author-name-on'] = array(
		'id' => 'single-author-name-on',
		'label'   => __( 'Show author name on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['single-date-on'] = array(
		'id' => 'single-date-on',
		'label'   => __( 'Show published date on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['single-comment-on'] = array(
		'id' => 'single-comment-on',
		'label'   => __( 'Show comments count on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	
	
	$options['single-featured-on'] = array(
		'id' => 'single-featured-on',
		'label'   => __( 'Show featured image on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);	

	$options['single-like-on'] = array(
		'id' => 'single-like-on',
		'label'   => __( 'Show likes button on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);		

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Show author box on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Show related posts on single post', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['close-comments-on'] = array(
		'id' => 'close-comments-on',
		'label'   => __( 'Close comment list and comment form', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);

	$options['right-twitter-on'] = array(
		'id' => 'right-twitter-on',
		'label'   => __( 'Show Twitter link on site bottom right', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['right-facebook-on'] = array(
		'id' => 'right-facebook-on',
		'label'   => __( 'Show Facebook link on site bottom right', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Show "back to top" link on site bottom right', 'myportal' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['partners-title'] = array(
		'id' => 'partners-title',
		'label'   => __( 'Partners Section Title', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('Our Partners', 'myportal'),
	);	

	$options['friend-title'] = array(
		'id' => 'friend-title',
		'label'   => __( 'Recommended Section Title', 'myportal' ),
		'section' => $section,
		'type'    => 'text',
		'default' => __('We Recommended', 'myportal'),
	);		

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Site Info', 'myportal' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - <a href="http://www.happythemes.com/wordpress-themes/myportal/" target="_blank">WordPress Theme</a> by <a href="http://www.happythemes.com/" target="_blank">HappyThemes</a>'
	);		
	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'myportal' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );