<?php

/**
 * newsnow_pro functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package myportal
 */

function myportal_setup() {

    load_theme_textdomain('myportal', get_template_directory() . '/languages');

    // Add default posts and comments RSS feed links to head.
    add_theme_support('automatic-feed-links');

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support('title-tag');

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
     */
    add_theme_support('post-thumbnails');

    // This theme uses wp_nav_menu() in one location.
    register_nav_menus(array(
        'primary' => esc_html__('Primary Menu', 'myportal'),
        'secondary' => esc_html__('Secondary Menu', 'myportal'),
        'friend' => esc_html__('Recommended Menu', 'myportal'),
        'footer' => esc_html__('Footer Menu', 'myportal'),
    ));

    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support('html5', array(
        'search-form',
        'comment-form',
        'comment-list',
        'gallery',
        'caption',
    ));

    // Set up the WordPress core custom background feature.
    add_theme_support('custom-background', apply_filters('myportal_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => '',
    )));

    // Add support for Block Styles.
    add_theme_support('wp-block-styles');

    // Add support for editor styles.
    add_theme_support('editor-styles');

    // Enqueue editor styles.
    add_editor_style('style-editor.css');

    // Add theme support for selective refresh for widgets.
    add_theme_support('customize-selective-refresh-widgets');

    // Add support for responsive embeds.
    add_theme_support('responsive-embeds');
}
add_action('after_setup_theme', 'myportal_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function myportal_content_width() {
    $GLOBALS['content_width'] = apply_filters('myportal_content_width', 760);
}
add_action('after_setup_theme', 'myportal_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function myportal_sidebar_init() {

    register_sidebar(array(
        'name'          => esc_html__('Right Sidebar (General)', 'myportal'),
        'id'            => 'sidebar-1',
        'description'   => esc_html__('Add widgets here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2 class="widget-title"><span>',
        'after_title'   => '</span></h2>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Right Sidebar (Home)', 'myportal'),
        'id'            => 'homepage-sidebar',
        'description'   => esc_html__('Add widgets here (optional). If there is no widgets, the homepage will use the "Right Sidebar (General)".', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2 class="widget-title"><span>',
        'after_title'   => '</span></h2>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Home Content', 'myportal'),
        'id'            => 'homepage',
        'description'   => esc_html__('Add the "Home Content 1/2 Columns" and "Ads" widget only.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2 class="widget-title"><span>',
        'after_title'   => '</span></h2>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Footer 1', 'myportal'),
        'id'            => 'footer-1',
        'description'   => esc_html__('Add widgets here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));
    register_sidebar(array(
        'name'          => esc_html__('Footer 2', 'myportal'),
        'id'            => 'footer-2',
        'description'   => esc_html__('Add widgets here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));
    register_sidebar(array(
        'name'          => esc_html__('Footer 3', 'myportal'),
        'id'            => 'footer-3',
        'description'   => esc_html__('Add widgets here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Footer 4', 'myportal'),
        'id'            => 'footer-4',
        'description'   => esc_html__('Add widgets here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Partners', 'myportal'),
        'id'            => 'footer-partners',
        'description'   => esc_html__('Add the "Image" widget only.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="partner-image %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<div class="widget-title">',
        'after_title'   => '</div>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Header Ad', 'myportal'),
        'id'            => 'header-ad',
        'description'   => esc_html__('Add the "Ads" widget here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="widget container header-ad %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Content List Ad', 'myportal'),
        'id'            => 'content-ad',
        'description'   => esc_html__('Add the "Ads" widget here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="content-ad %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Post Top Ad', 'myportal'),
        'id'            => 'single-top-ad',
        'description'   => esc_html__('Add the "Ads" widget here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="single-top-ad %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));

    register_sidebar(array(
        'name'          => esc_html__('Post Bottom Ad', 'myportal'),
        'id'            => 'single-bottom-ad',
        'description'   => esc_html__('Add the "Ads" widget here.', 'myportal'),
        'before_widget' => '<div id="%1$s" class="single-bottom-ad %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>',
    ));
}
add_action('widgets_init', 'myportal_sidebar_init');

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */

require get_template_directory() . '/admin/customizer-library.php';

require get_template_directory() . '/admin/customizer-options.php';

require get_template_directory() . '/admin/styles.php';

require get_template_directory() . '/admin/mods.php';

require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/* Demo Content*/
require_once dirname(__FILE__) . '/demo-content/setup.php';

/**
 * Load plugins.
 */
require get_template_directory() . '/inc/plugins.php';


/**
 * Registers custom widgets.
 */
function myportal_widgets_init() {

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-popular.php';
    register_widget('myportal_Popular_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-recent.php';
    register_widget('myportal_Recent_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-random.php';
    register_widget('myportal_Random_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-views.php';
    register_widget('myportal_Views_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-newsletter.php';
    register_widget('myportal_Newsletter_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-ad.php';
    register_widget('myportal_Ad_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-home-block-one.php';
    register_widget('myportal_Block_One_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-home-block-one-b.php';
    register_widget('myportal_Block_One_B_Widget');

    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-home-block-two.php';
    register_widget('myportal_Block_Two_Widget');
}
add_action('widgets_init', 'myportal_widgets_init');

/* Fix PHP warning */
function _get($str) {
    $val = !empty($_GET[$str]) ? $_GET[$str] : null;
    return $val;
}

/**
 * Simple Likes
 */
if (get_theme_mod('single-like-on', true) == true) {
    require trailingslashit(get_template_directory()) . 'inc/post-like.php';
}

/**
 * Category Images
 */
require trailingslashit(get_template_directory()) . 'inc/categories-images.php';

/**
 * Enqueues scripts and styles.
 */
function myportal_scripts() {

    // load jquery if it isn't

    //wp_enqueue_script('jquery');
    wp_enqueue_script('jquery', get_template_directory_uri() . '/assets/js/jquery.js', array(), '', true);

    //  Enqueues Javascripts
    wp_enqueue_script('superfish', get_template_directory_uri() . '/assets/js/superfish.js', array(), '', true);
    wp_enqueue_script('modernizr', get_template_directory_uri() . '/assets/js/modernizr.min.js', array(), '', true);
    wp_enqueue_script('html5', get_template_directory_uri() . '/assets/js/html5.js', array(), '', true);
    wp_enqueue_script('bxslider', get_template_directory_uri() . '/assets/js/jquery.bxslider.min.js', array(), '', true);

    if (get_theme_mod('pagination-style', 'choice-1') == 'choice-1') {
        wp_enqueue_script('infinite-scroll', get_template_directory_uri() . '/assets/js/infinite-scroll.pkgd.min.js', array(), '', true);
    }

    wp_enqueue_script('custom', get_template_directory_uri() . '/assets/js/jquery.custom.js', array(), '20190505', true);

    // Enqueues CSS styles
    // Enqueues CSS styles
    $theme_version = wp_get_theme()->get('Version');
    wp_enqueue_style('myportal-style', get_stylesheet_uri(), array(), $theme_version);
    wp_style_add_data('myportal-style', 'rtl', 'replace');
    wp_enqueue_style('genericons-style',   get_template_directory_uri() . '/genericons/genericons.css');

    if (get_theme_mod('site-layout', 'choice-1') == 'choice-1') {
        wp_enqueue_style('responsive-style',   get_template_directory_uri() . '/responsive.css', array(), '20190511');
    }

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'myportal_scripts');

/* Admin CSS Style */
function myportal_admin_style() {
    wp_enqueue_style('admin-style', get_template_directory_uri() . '/assets/css/admin.css');
}
add_action('admin_enqueue_scripts', 'myportal_admin_style');

/**
 * Post Thumbnails.
 */
if (function_exists('add_theme_support')) {
    add_theme_support('post-thumbnails');
    //set_post_thumbnail_size( 150, 150, true ); // default Post Thumbnail dimensions (cropped)
    add_image_size('featured_large_thumb', 790, 474, true);
    add_image_size('featured_small_thumb', 300, 180, true);
    add_image_size('block_large_thumb', 300, 180, true);
    add_image_size('post_thumb', 300, 180, true);
    add_image_size('single_thumb', 790, 474, true);
    add_image_size('widget_thumb', 300, 150, true);
}
