<?php
/**
 * Home block one widget.
 *
 * @package    myportal
 * @author     Zhutibaba
 * @copyright  Copyright (c) 2017, Zhutibaba
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class myportal_Block_One_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-myportal-home-block-one',
			'description' => __( 'Only use for "Home Content".', 'myportal' )
		);

		// Create the widget.
		parent::__construct(
			'happythemes-home-block-one',          // $this->id_base
			__( '&raquo; Home - 1 Column', 'myportal' ), // $this->name
			$widget_options                    // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Theme prefix
			$prefix = 'myportal-';

			// Pull the selected category.
			$cat_id = isset( $instance['cat'] ) ? absint( $instance['cat'] ) : 0;

			// Get the category.
			$category = get_category( $cat_id );

			// Get the category archive link.
			$cat_link = get_category_link( $cat_id );

			// Limit to category based on user selected tag.
			if ( ! $cat_id == 0 ) {
				$args['cat'] = $cat_id;
			}

 ?>

				<div class="content-block content-block-1 clear">

					<div class="section-heading">

					<?php
						if ( ( ! empty( $instance['title'] ) ) && ( $cat_id != 0 ) ) {
							echo '<h3 class="section-title"><a href="' . esc_url( $cat_link ) . '">' . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . '</a></h3>';
						} elseif ( $cat_id == 0 ) {
							echo '<h3 class="section-title"><span>' . __( 'Latest Posts', 'myportal' ) . '</span></h3>';
						} else {
							echo '<h3 class="section-title"><a href="' . esc_url( $cat_link ) . '">' . esc_attr( $category->name ) . '</a></h3>';
						}
					?>
					<ul class="section-more">

						<?php if ( ( ! empty( $instance['text1'] ) ) && ( ! empty( $instance['link1'] ) ) ) { ?>
						<li><a href="<?php echo esc_url($instance['link1']); ?>" ><?php echo esc_html($instance['text1']); ?></a></li>
						<?php } ?>

						<?php if ( ( ! empty( $instance['text2'] ) ) && ( ! empty( $instance['link2'] ) ) ) { ?>
						<li><a href="<?php echo esc_url($instance['link2']); ?>" ><?php echo esc_html($instance['text2']); ?></a></li>
						<?php } ?>

						<?php if ( ( ! empty( $instance['text3'] ) ) && ( ! empty( $instance['link3'] ) ) ) { ?>
						<li><a href="<?php echo esc_url($instance['link3']); ?>" ><?php echo esc_html($instance['text3']); ?></a></li>
						<?php } ?>
					</ul>

					</div><!-- .section-heading -->			

					<div class="col-left">

					<?php

						// Define custom query args
						$args = array( 
							'post_type'      => 'post',
							//'posts_per_page' => ( ! empty( $instance['limit'] ) ) ? absint( $instance['limit'] ) : 5,
							'posts_per_page' => 4,
							'post__not_in' => get_option( 'sticky_posts' ),
							'cat' => $cat_id
						);  

						global $wp_query;

						$merged_query_args = array_merge( $wp_query->query, $args );

						query_posts( $merged_query_args );

						$i = 1;

						if ( $wp_query->have_posts() ) :

						while ( $wp_query->have_posts() ) : $wp_query->the_post(); 

						if ($i < 5) { 
					?>

					<div class="post-big hentry">

						<a class="thumbnail-link" href="<?php the_permalink(); ?>">
							<div class="thumbnail-wrap">
								<?php if( has_post_thumbnail() ) { ?>
									<?php 
										the_post_thumbnail('block_large_thumb');
									?>
								<?php } ?>				
							</div><!-- .thumbnail-wrap -->
						</a>

						<div class="entry-header">
							<h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php myportal_home_post_title(); ?></a></h2>
						</div><!-- .entry-header -->

					</div><!-- .hentry -->

					<?php } else { ?>

					<div class="post-small hentry <?php echo( $wp_query->current_post + 1 === $wp_query->post_count ) ? 'last' : ''; ?>">


						<div class="entry-header">

							<h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php myportal_home_post_title(); ?></a></h2>

						</div><!-- .entry-header -->

					</div><!-- .hentry -->

					<?php 
						}
						$i++;
						endwhile; 
					?>

					</div><!-- .col-left -->

					<div class="col-right">

					<?php

						// Define custom query args
						$args = array( 
							'post_type'      => 'post',
							//'posts_per_page' => ( ! empty( $instance['limit'] ) ) ? absint( $instance['limit'] ) : 5,
							'posts_per_page' => (absint( $instance['limit'] ) - 4),
							'offset' => 4,
							'post__not_in' => get_option( 'sticky_posts' ),
							'cat' => $cat_id
						);  

						global $wp_query;

						$merged_query_args = array_merge( $wp_query->query, $args );

						query_posts( $merged_query_args );

						$i = 1;

						if ( $wp_query->have_posts() ) :

						while ( $wp_query->have_posts() ) : $wp_query->the_post(); 

						if ($i < 25) { 
					?>

					<div class="post-small hentry <?php echo( $wp_query->current_post + 1 === $wp_query->post_count ) ? 'last' : ''; ?>">


						<div class="entry-header">

							<h2 class="entry-title"><a href="<?php the_permalink(); ?>" ><?php myportal_custom_title(); ?></a></h2>

						</div><!-- .entry-header -->

					</div><!-- .hentry -->

					<?php 
						}
						$i++;
						endwhile; 
						endif;
					?>

					</div><!-- .col-right -->					

				</div><!-- .content-block-1 -->

			<?php 
			endif;
			wp_reset_query();
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['limit'] = (int) $new_instance['limit'];
		$instance['cat']   = (int) $new_instance['cat'];
		$instance['text1']   = strip_tags( $new_instance['text1'] );
		$instance['text2']   = strip_tags( $new_instance['text2'] );
		$instance['text3']   = strip_tags( $new_instance['text3'] );
		$instance['link1']   = strip_tags( $new_instance['link1'] );
		$instance['link2']   = strip_tags( $new_instance['link2'] );
		$instance['link3']   = strip_tags( $new_instance['link3'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title' => '',
			'limit' => 11,
			'cat'   => '',
			'text1' => '',
			'text2' => '',
			'text3' => '',
			'link1' => home_url(),
			'link2' => home_url(),
			'link3' => home_url()
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php _e( 'Title', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Choose a category', 'myportal' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<option value="0"><?php _e( 'All categories &hellip;', 'myportal' ); ?></option>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo esc_attr( $category->term_id ); ?>" <?php selected( $instance['cat'], $category->term_id ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php _e( 'Number of posts to show', 'myportal' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['limit'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'text1' ); ?>">
				<?php _e( 'Sub Menu Title 1', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'text1' ); ?>" name="<?php echo $this->get_field_name( 'text1' ); ?>" value="<?php echo esc_attr( $instance['text1'] ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'link1' ); ?>">
				<?php _e( 'Link URL 1', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'link1' ); ?>" name="<?php echo $this->get_field_name( 'link1' ); ?>" value="<?php echo esc_attr( $instance['link1'] ); ?>" placeholder="http://"/>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'text2' ); ?>">
				<?php _e( 'Sub Menu Title 2', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'text2' ); ?>" name="<?php echo $this->get_field_name( 'text2' ); ?>" value="<?php echo esc_attr( $instance['text2'] ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'link2' ); ?>">
				<?php _e( 'Link URL 2', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'link2' ); ?>" name="<?php echo $this->get_field_name( 'link2' ); ?>" value="<?php echo esc_attr( $instance['link2'] ); ?>" placeholder="http://" />
		</p>	

		<p>
			<label for="<?php echo $this->get_field_id( 'text3' ); ?>">
				<?php _e( 'Sub Menu Title 3', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'text3' ); ?>" name="<?php echo $this->get_field_name( 'text3' ); ?>" value="<?php echo esc_attr( $instance['text3'] ); ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'link3' ); ?>">
				<?php _e( 'Link URL 3', 'myportal' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'link3' ); ?>" name="<?php echo $this->get_field_name( 'link3' ); ?>" value="<?php echo esc_attr( $instance['link3'] ); ?>" placeholder="http://"/>
		</p>										

	<?php

	}

}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function myportal_home_one_column_meta() {

	// Set up empty html
	$html = '';

	// Open wrapper
	$html = '<div class="entry-meta">';
		$category = get_the_category( get_the_ID() );
		if ( $category && myportal_categorized_blog() ) {
			$html .= '<span class="entry-category">' . esc_attr( $category[0]->name ) . '</span>';
		}
		$html .= ' <span class="sep">|</span> ';
		$html .= '<span class="entry-date"><time class="published" datetime="' . esc_html( get_the_date( 'c' ) ) . '">' . esc_html( get_the_date() ) . '</time></span>';
	$html .= '</div>';

	return $html;

}